@@ -9,7 +9,7 @@ require      Exporter;
 our @ISA = qw (Exporter);
 our @EXPORT = qw (baseconfigure verbosity freezeverbosity dumper);
 
-our $VERSION = "1.24";
+our $VERSION = "1.25";
 
 $Baseobject::directfeedback=0; # for downward compatibility
 $Baseobject::quickdeath=0;
@@ -336,7 +336,7 @@ sub verbose {
 	my ($package, $file, $line) = caller;
 	my $string = join('', @_);
 	chomp($string);
-	print STDERR "$string at $file line $line (debug)" if verbosity >= 1;
+	print STDERR "$string at $file line $line (verbose)" if verbosity >= 1;
 
 }
 
